=======
Modules
=======

.. automodule:: memcnn
  :members: is_invertible_module

.. autoclass:: memcnn.InvertibleModuleWrapper
  :members: forward, inverse

.. autoclass:: memcnn.AdditiveCoupling
  :members: forward, inverse

.. autoclass:: memcnn.AffineCoupling
  :members: forward, inverse

.. autoclass:: memcnn.AffineAdapterNaive

.. autoclass:: memcnn.AffineAdapterSigmoid

.. autoclass:: memcnn.ReversibleBlock
  :members: forward, inverse
